# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-17 19:55
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='AutoMenu',
            fields=[
                ('selector', models.CharField(help_text='Selector for elements that should become anchors.', max_length=255, verbose_name='Selector')),
                ('template', models.CharField(choices=[(b'default', 'Default')], default=b'default', max_length=255, verbose_name='Template')),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_custommenu_automenu', serialize=False, to='cms.CMSPlugin')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
