# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-03-04 21:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('djangocms_custommenu', '0009_custommenu'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='stylemenu',
            name='cmsplugin_ptr',
        ),
        migrations.RemoveField(
            model_name='stylemenu',
            name='root_page',
        ),
        migrations.DeleteModel(
            name='StyleMenu',
        ),
    ]
