# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-18 16:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0002_stylemenu'),
    ]

    operations = [
        migrations.AddField(
            model_name='stylemenu',
            name='configuration',
            field=models.TextField(blank=True, help_text='Custom configuration.'),
        ),
    ]
