# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-20 11:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0006_auto_20180220_1039'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stylemenu',
            name='template',
            field=models.CharField(choices=[(b'default', 'Default'), (b'zoom-masonry', 'Zoom masonry'), (b'dropdown-image', 'Dropdown image')], default=b'default', max_length=255, verbose_name='Template'),
        ),
    ]
