# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-20 08:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0004_auto_20180220_0908'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stylemenu',
            name='end_level',
            field=models.PositiveSmallIntegerField(default=100, help_text='At which level the navigation tree should stop.', verbose_name='End level'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='extra_active',
            field=models.PositiveSmallIntegerField(default=100, help_text='How many levels of descendants of the currently active node should be displayed.', verbose_name='Extra active'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='extra_inactive',
            field=models.PositiveSmallIntegerField(default=0, help_text='How many levels of navigation should be displayed if a node is not a direct ancestor or descendant of the current active node.', verbose_name='Extra inactive'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='levels',
            field=models.PositiveSmallIntegerField(default=100, help_text='At which level the navigation tree should stop.', verbose_name='Levels'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='nephews',
            field=models.PositiveSmallIntegerField(default=100, help_text='How many levels of nephews (children of siblings) are shown.', verbose_name='Nephews'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='root_level',
            field=models.PositiveSmallIntegerField(blank=True, help_text='At what level, if any, the menu should have its root.', null=True, verbose_name='Root level'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='start_level',
            field=models.PositiveSmallIntegerField(default=0, help_text='From which level the navigation should be rendered.', verbose_name='Start level'),
        ),
    ]
