# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-20 09:39
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0005_auto_20180220_0912'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stylemenu',
            name='menu_type',
            field=models.CharField(choices=[(b'show_menu', 'Show menu'), (b'show_sub_menu', 'Show sub menu')], default=b'show_menu', help_text='Check documentation here http://docs.django-cms.org/en/release-3.4.x/reference/navigation.html', max_length=255, verbose_name='Menu type'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='root_page',
            field=models.ForeignKey(blank=True, help_text='Menu tree starts from this page. Warning: selected page MUST have its ID set in advanced settings.', null=True, on_delete=django.db.models.deletion.CASCADE, to='cms.Page', verbose_name='Root page'),
        ),
    ]
